==> 2.5.0.zip: cloudlog/application/language/dutch/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Directe toegang tot scripts is niet toegestaan');

$lang['error_no_active_station_profile'] = 'Let op: Activeer een station profiel.';

$lang['notice_turn_the_radio_on'] = 'Je hebt vandaag nog geen QSOs gemaakt. Tijd om de set aan te zetten!';

$lang['general_word_important'] = 'Belangrijk';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Choose file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";

$lang['general_word_date'] = 'Datum';
$lang['general_word_time'] = 'Tijd';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Date/Time';
$lang['general_word_none'] = 'Geen';
$lang['general_word_name'] = 'Naam';
$lang['general_word_location'] = 'Locatie';
$lang['general_word_comment'] = 'Opmerking';
$lang['general_word_general'] = 'Algemeen';
$lang['general_word_satellite'] = 'Satelliet';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Aantekeningen';
$lang['general_word_country'] = 'Land';
$lang['general_word_city'] = 'By';

$lang['general_word_total'] = 'Totaal';
$lang['general_word_year'] = 'Jaar';
$lang['general_word_month'] = 'Maand';

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Gewerkt';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Bevestigd';
$lang['general_word_needed'] = 'Nodig';

$lang['general_word_all'] = 'All';
$lang['general_word_sent'] = 'Verzonden';
$lang['general_word_yes'] = 'Yes';
$lang['general_word_method'] = 'Method';

$lang['general_word_sent'] = 'Sent';
$lang['general_word_received'] = 'Ontvangen';
$lang['general_word_requested'] = 'Aangevraagd';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL Card';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL kaarten';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Wijzig QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Markeer QSL ontvangen (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Markeer QSL ontvangen (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Markeer QSL ontvangen (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Markeer QSL udsendt (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Markeer QSL udsendt (Direct)';
$lang['general_mark_qsl_requested'] = 'Markeer QSL Kort anmodet om';
$lang['general_mark_qsl_requested_bureau'] = 'Markeer QSL Kort anmodet om (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Markeer QSL Kort anmodet om (Direct)';
$lang['general_mark_qsl_not_required'] = 'Markeer QSL Kort ikke påkrævet';

$lang['general_delete_qso'] = 'Wis QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Total Distance';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Station Profiel';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Roepletters';
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Verzonden';
$lang['gen_hamradio_rst_rcvd'] = 'Ontvangen';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequentie';
$lang['gen_hamradio_frequency_rx'] = 'Frequentie (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Verz (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Ontv (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Vermogen (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagattie Mode';

$lang['gen_hamradio_satellite_name'] = 'Satelliet Naam';
$lang['gen_hamradio_satellite_mode'] = 'Satelliet Mode';

$lang['gen_hamradio_logbook'] = 'Logboek';

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA Staat';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referentie';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referentie';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referentie';
$lang['gen_hamradio_pota_reference'] = 'POTA Referentie';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then ";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then ";
$lang['gen_find_zone_part2'] = 'click here';
$lang['gen_find_zone_part3'] = ' to find it!';

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Je hebt';
$lang['dashboard_qsos_today'] = 'QSOs vandaag!';
$lang['dashboard_qso_breakdown'] = 'QSOs overzicht';
$lang['dashboard_countries_breakdown'] = 'Landen overzicht';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'From date';

$lang['gen_this_qso_was_confirmed_on'] = 'This QSO was confirmed on';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

==> 2.6.4.zip: cloudlog/application/language/dutch/general_words_lang.php <==
<?php

defined('BASEPATH') OR exit('Directe toegang tot scripts is niet toegestaan');

$lang['error_no_active_station_profile'] = 'Let op: Activeer een station profiel.';

$lang['notice_turn_the_radio_on'] = 'Je hebt vandaag nog geen QSOs gemaakt. Tijd om de set aan te zetten!';

$lang['general_word_important'] = 'Belangrijk';
$lang['general_word_warning'] = 'Warning';
$lang['general_word_danger'] = 'DANGER';
$lang['general_word_maintenance'] = 'Maintenance';
$lang['general_word_info'] = 'Info';
$lang['general_word_choose_file'] = 'Choose file';
$lang['general_word_next'] = 'Next';
$lang['general_word_previous'] = 'Previous';
$lang['general_word_cancel'] = "Cancel";
$lang['general_word_ok'] = "OK";
$lang['general_word_attention'] = "Attention";
$lang['general_word_enabled'] = "Enabled";
$lang['general_word_disabled'] = "Disabled";
$lang['general_word_export'] = "Export";
$lang['general_word_import'] = "Import";
$lang['general_word_count'] = "Count";
$lang['general_word_filtering_on'] = "Filtering on";
$lang['general_word_not_display'] = "Not display";
$lang['general_word_icon'] = "Icon";
$lang['general_word_never'] = "Never";

$lang['general_word_date'] = 'Datum';
$lang['general_word_startdate'] = "Start Date";
$lang['general_word_enddate'] = "End Date";
$lang['general_word_time'] = 'Tijd';
$lang['general_word_time_on'] = 'Time on';
$lang['general_word_time_off'] = 'Time off';
$lang['general_word_datetime'] = 'Date/Time';
$lang['general_word_none'] = 'Geen';
$lang['general_word_name'] = 'Naam';
$lang['general_word_location'] = 'Locatie';
$lang['general_word_comment'] = 'Opmerking';
$lang['general_word_general'] = 'Algemeen';
$lang['general_word_satellite'] = 'Satelliet';
$lang['general_word_satellite_short'] = 'Sat';
$lang['general_word_notes'] = 'Aantekeningen';
$lang['general_word_country'] = 'Land';
$lang['general_word_city'] = 'By';

$lang['general_word_total'] = 'Totaal';
$lang['general_word_year'] = 'Jaar';
$lang['general_word_month'] = 'Maand';
$lang['general_word_day'] = "Day";
$lang['general_word_days'] = "Days";

$lang['general_word_colors'] = "Colors";
$lang['general_word_light'] = "Light/Laser";
$lang['general_word_worked'] = 'Gewerkt';
$lang['general_word_worked_not_confirmed'] = "Worked not confirmed";
$lang['general_word_not_worked'] = "Not worked";
$lang['general_word_confirmed'] = 'Bevestigd';
$lang['general_word_confirmation'] = "Confirmation";
$lang['general_word_needed'] = 'Nodig';

$lang['general_word_all'] = 'All';
$lang['general_word_sent'] = 'Verzonden';
$lang['general_word_yes'] = 'Yes';
$lang['general_word_method'] = 'Method';

$lang['general_word_sent'] = 'Sent';
$lang['general_word_received'] = 'Ontvangen';
$lang['general_word_requested'] = 'Aangevraagd';
$lang['general_word_queued'] = 'Queued';
$lang['general_word_table'] = "Table";
$lang['general_word_invalid_ignore'] = 'Invalid (Ignore)';
$lang['general_word_qslcard'] = 'QSL Card';
$lang['general_word_qslcard_management'] = 'QSL Management';
$lang['general_word_qslcards'] = 'QSL kaarten';
$lang['general_word_qslcard_direct'] = 'Direct';
$lang['general_word_qslcard_bureau'] = 'Bureau';
$lang['general_word_qslcard_electronic'] = 'Electronic';
$lang['general_word_qslcard_manager'] = 'Manager';
$lang['general_word_qslcard_via'] = 'Via';
$lang['general_word_eqslcard'] = 'eQSL Card';
$lang['general_word_eqslcards'] = 'eQSL Cards';
$lang['general_word_lotw'] = 'Logbook of the World';
$lang['general_word_lotw_short'] = 'LoTW';

$lang['general_word_details'] = 'Details';
$lang['general_word_qso_data'] = 'QSO Data';

$lang['general_edit_qso'] = 'Wijzig QSO';
$lang['general_mark_qsl_rx_bureau'] = 'Markeer QSL ontvangen (Bureau)';
$lang['general_mark_qsl_rx_direct'] = 'Markeer QSL ontvangen (Direct)';
$lang['general_mark_qsl_rx_electronic'] = 'Markeer QSL ontvangen (Electronic)';
$lang['general_mark_qsl_tx_bureau'] = 'Markeer QSL udsendt (Bureau)';
$lang['general_mark_qsl_tx_direct'] = 'Markeer QSL udsendt (Direct)';
$lang['general_mark_qsl_requested'] = 'Markeer QSL Kort anmodet om';
$lang['general_mark_qsl_requested_bureau'] = 'Markeer QSL Kort anmodet om (Bureau)';
$lang['general_mark_qsl_requested_direct'] = 'Markeer QSL Kort anmodet om (Direct)';
$lang['general_mark_qsl_not_required'] = 'Markeer QSL Kort ikke påkrævet';

$lang['general_delete_qso'] = 'Wis QSO';
$lang['general_more_qso'] = 'More QSOs';

$lang['general_lookup_qrz'] = 'Lookup on QRZ.com';
$lang['general_lookup_hamqth'] = 'Lookup on HamQTH';

$lang['general_total_distance'] = 'Total Distance';

// PHP Upload Warning
$lang['gen_max_file_upload_size'] = 'Maximum file upload size is ';

// Cloudlog Terms
$lang['cloudlog_station_profile'] = 'Station Profiel';

// ham radio terms
$lang['gen_hamradio_cq'] = "CQ";
$lang['gen_hamradio_qso'] = 'QSO';
$lang['gen_hamradio_station'] = 'Station';

$lang['gen_hamradio_call'] = 'Call';
$lang['gen_hamradio_callsign'] = 'Roepletters';
$lang['gen_hamradio_prefix'] = "Prefix";
$lang['gen_hamradio_suffix'] = "Suffix";
$lang['gen_hamradio_de'] = 'De';
$lang['gen_hamradio_dx'] = 'Dx';
$lang['gen_hamradio_mode'] = 'Mode';
$lang['gen_hamradio_rst_sent'] = 'Verzonden';
$lang['gen_hamradio_rst_rcvd'] = 'Ontvangen';
$lang['gen_hamradio_band'] = 'Band';
$lang['gen_hamradio_bandgroup'] = "Bandgroup";
$lang['gen_hamradio_band_rx'] = 'Band (RX)';
$lang['gen_hamradio_frequency'] = 'Frequentie';
$lang['gen_hamradio_frequency_rx'] = 'Frequentie (RX)';
$lang['gen_hamradio_radio'] = 'Radio';
$lang['gen_hamradio_rsts'] = 'RST (S)';
$lang['gen_hamradio_rstr'] = 'RST (R)';
$lang['gen_hamradio_refs'] = 'Refs';
$lang['gen_hamradio_myrefs'] = 'My Refs';
$lang['gen_hamradio_exchange_sent_short'] = 'Verz (S)';
$lang['gen_hamradio_exchange_rcvd_short'] = 'Ontv (R)';
$lang['gen_hamradio_qsl'] = 'QSL';
$lang['gen_hamradio_qsltype'] = "QSL Type";
$lang['gen_hamradio_qslvia'] = 'QSL via';
$lang['gen_hamradio_qslmsg'] = 'QSL Msg';
$lang['gen_hamradio_locator'] = 'Locator';
$lang['gen_hamradio_transmit_power'] = 'Vermogen (W)';
$lang['gen_hamradio_propagation_mode'] = 'Propagattie Mode';

$lang['gen_hamradio_satellite_name'] = 'Satelliet Naam';
$lang['gen_hamradio_satellite_mode'] = 'Satelliet Mode';

$lang['gen_hamradio_logbook'] = 'Logboek';
$lang['gen_hamradio_award'] = "Award";

$lang['gen_hamradio_zones'] = 'Zones';
$lang['gen_hamradio_cq_zone'] = 'CQ Zone';
$lang['gen_hamradio_itu_zone'] = 'ITU Zone';
$lang['gen_hamradio_dxcc'] = 'DXCC';
$lang['gen_hamradio_deleted_dxcc'] = 'Deleted DXCC';
$lang['gen_hamradio_continent'] = 'Continent';
$lang['gen_hamradio_usa_state'] = 'USA Staat';
$lang['gen_hamradio_county_reference'] = 'USA County';
$lang['gen_hamradio_iota_reference'] = 'IOTA Referentie';
$lang['gen_hamradio_sota_reference'] = 'SOTA Referentie';
$lang['gen_hamradio_wwff_reference'] = 'WWFF Referentie';
$lang['gen_hamradio_pota_reference'] = 'POTA Referentie';
$lang['gen_hamradio_dok'] = 'DOK';
$lang['gen_hamradio_state'] = 'State';
$lang['gen_hamradio_iota'] = 'IOTA';
$lang['gen_hamradio_sota'] = 'SOTA';
$lang['gen_hamradio_wwff'] = 'WWFF';
$lang['gen_hamradio_pota'] = 'POTA';
$lang['gen_hamradio_gridsquare'] = 'Gridsquare';
$lang['gen_hamradio_get_gridsquare'] = 'Get Gridsquare';
$lang['gen_hamradio_gridsquare_show'] = "Show Locator";
$lang['gen_hamradio_latitude'] = "Latitude";
$lang['gen_hamradio_longitude'] = "Longitude";
$lang['gen_hamradio_bearing'] = "Bearing";
$lang['gen_hamradio_distance'] = 'Distance';
$lang['gen_hamradio_operator'] = 'Operator';

$lang['gen_hamradio_sig'] = 'Sig';
$lang['gen_hamradio_sig_info'] = 'Sig Info';

// Find your CQ/ITU Zone
$lang['gen_find_zone_cq_part1'] = "If you don't know your CQ Zone then";
$lang['gen_find_zone_itu_part1'] = "If you don't know your ITU Zone then";
$lang['gen_find_zone_part2'] = "click here";
$lang['gen_find_zone_part3'] = "to find it!";

// Dashboard Words
$lang['dashboard_you_have_had'] = 'Je hebt';
$lang['dashboard_qsos_today'] = 'QSOs vandaag!';
$lang['dashboard_qso_breakdown'] = 'QSOs overzicht';
$lang['dashboard_countries_breakdown'] = 'Landen overzicht';
$lang['gen_to_date'] = 'To date';

$lang['gen_from_date'] = 'From date';

$lang['gen_this_qso_was_confirmed_on'] = 'This QSO was confirmed on';

$lang['error_no_logbook_found'] = 'No logbooks were found. You need to define a logbook under Station Logbooks! Do it here:';

$lang['copy_to_clipboard'] = 'Copy to clipboard';

$lang['africa'] = 'Africa';
$lang['antarctica'] = 'Antarctica';
$lang['asia'] = 'Asia';
$lang['europe'] = 'Europe';
$lang['northamerica'] = 'North America';
$lang['oceania'] = 'Oceania';
$lang['southamerica'] = 'South America';

$lang['gen_band_selection'] = 'Band selection';
$lang['general_word_today'] = 'Today';

$lang['dashboard_php_version_warning'] = 'You need to upgrade your PHP version. Minimum version is 7.4. Your version is';
$lang['dashboard_country_files_warning'] = 'You need to update country files! Go <a href="'.site_url('update').'">here</a> to do it!';
$lang['dashboard_locations_warning'] = 'You have no station locations. Go <a href="'. site_url('station') . '">here</a> to create it!';
$lang['dashboard_logbooks_warning'] = 'You have no station logbook. Go <a href="'. site_url('logbooks') . '">here</a> to create it!';

$lang['hams_at_no_activations_found'] = 'No upcoming activations found. Please check back later.';

$lang['datatables_language'] = "en-GB";
